==> qtwayland-6.10.1-2.gpkg.tar: image/usr/src/debug/dev-qt/qtwayland-6.10.1/qtwayland-everywhere-src-6.10.1_build/src/imports/compositor-extensions/wlshell/.qt/rcc/qrc_qmake_QtWayland_Compositor_WlShell.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x1,0x8,
  0x6d,
  0x6f,0x64,0x75,0x6c,0x65,0x20,0x51,0x74,0x57,0x61,0x79,0x6c,0x61,0x6e,0x64,0x2e,
  0x43,0x6f,0x6d,0x70,0x6f,0x73,0x69,0x74,0x6f,0x72,0x2e,0x57,0x6c,0x53,0x68,0x65,
  0x6c,0x6c,0xa,0x6c,0x69,0x6e,0x6b,0x74,0x61,0x72,0x67,0x65,0x74,0x20,0x51,0x74,
  0x36,0x3a,0x3a,0x57,0x61,0x79,0x6c,0x61,0x6e,0x64,0x43,0x6f,0x6d,0x70,0x6f,0x73,
  0x69,0x74,0x6f,0x72,0x57,0x4c,0x53,0x68,0x65,0x6c,0x6c,0x70,0x6c,0x75,0x67,0x69,
  0x6e,0xa,0x6f,0x70,0x74,0x69,0x6f,0x6e,0x61,0x6c,0x20,0x70,0x6c,0x75,0x67,0x69,
  0x6e,0x20,0x77,0x61,0x79,0x6c,0x61,0x6e,0x64,0x63,0x6f,0x6d,0x70,0x6f,0x73,0x69,
  0x74,0x6f,0x72,0x77,0x6c,0x73,0x68,0x65,0x6c,0x6c,0x70,0x6c,0x75,0x67,0x69,0x6e,
  0xa,0x63,0x6c,0x61,0x73,0x73,0x6e,0x61,0x6d,0x65,0x20,0x51,0x74,0x57,0x61,0x79,
  0x6c,0x61,0x6e,0x64,0x5f,0x43,0x6f,0x6d,0x70,0x6f,0x73,0x69,0x74,0x6f,0x72,0x5f,
  0x57,0x6c,0x53,0x68,0x65,0x6c,0x6c,0x50,0x6c,0x75,0x67,0x69,0x6e,0xa,0x74,0x79,
  0x70,0x65,0x69,0x6e,0x66,0x6f,0x20,0x70,0x6c,0x75,0x67,0x69,0x6e,0x73,0x2e,0x71,
  0x6d,0x6c,0x74,0x79,0x70,0x65,0x73,0xa,0x70,0x72,0x65,0x66,0x65,0x72,0x20,0x3a,
  0x2f,0x71,0x74,0x2d,0x70,0x72,0x6f,0x6a,0x65,0x63,0x74,0x2e,0x6f,0x72,0x67,0x2f,
  0x69,0x6d,0x70,0x6f,0x72,0x74,0x73,0x2f,0x51,0x74,0x57,0x61,0x79,0x6c,0x61,0x6e,
  0x64,0x2f,0x43,0x6f,0x6d,0x70,0x6f,0x73,0x69,0x74,0x6f,0x72,0x2f,0x57,0x6c,0x53,
  0x68,0x65,0x6c,0x6c,0x2f,0xa,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // qt-project.org
  0x0,0xe,
  0x5,0x28,0x6c,0x87,
  0x0,0x71,
  0x0,0x74,0x0,0x2d,0x0,0x70,0x0,0x72,0x0,0x6f,0x0,0x6a,0x0,0x65,0x0,0x63,0x0,0x74,0x0,0x2e,0x0,0x6f,0x0,0x72,0x0,0x67,
    // imports
  0x0,0x7,
  0x0,0x47,0x69,0x53,
  0x0,0x69,
  0x0,0x6d,0x0,0x70,0x0,0x6f,0x0,0x72,0x0,0x74,0x0,0x73,
    // QtWayland
  0x0,0x9,
  0xd,0x90,0x99,0x64,
  0x0,0x51,
  0x0,0x74,0x0,0x57,0x0,0x61,0x0,0x79,0x0,0x6c,0x0,0x61,0x0,0x6e,0x0,0x64,
    // Compositor
  0x0,0xa,
  0x7,0x63,0x47,0xe2,
  0x0,0x43,
  0x0,0x6f,0x0,0x6d,0x0,0x70,0x0,0x6f,0x0,0x73,0x0,0x69,0x0,0x74,0x0,0x6f,0x0,0x72,
    // WlShell
  0x0,0x7,
  0xe,0x19,0xec,0x8c,
  0x0,0x57,
  0x0,0x6c,0x0,0x53,0x0,0x68,0x0,0x65,0x0,0x6c,0x0,0x6c,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/imports
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/imports/QtWayland
  0x0,0x0,0x0,0x36,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/imports/QtWayland/Compositor
  0x0,0x0,0x0,0x4e,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/imports/QtWayland/Compositor/WlShell
  0x0,0x0,0x0,0x68,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x6,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/imports/QtWayland/Compositor/WlShell/qmldir
  0x0,0x0,0x0,0x7c,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9a,0xf1,0x9,0xbc,0xcf,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_QtWayland_Compositor_WlShell)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_QtWayland_Compositor_WlShell)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_QtWayland_Compositor_WlShell)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_QtWayland_Compositor_WlShell)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_QtWayland_Compositor_WlShell)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_QtWayland_Compositor_WlShell)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif

==> qtwayland-6.10.2-1.gpkg.tar: image/usr/src/debug/dev-qt/qtwayland-6.10.2/qtwayland-everywhere-src-6.10.2_build/src/imports/compositor-extensions/wlshell/.qt/rcc/qrc_qmake_QtWayland_Compositor_WlShell.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x1,0x8,
  0x6d,
  0x6f,0x64,0x75,0x6c,0x65,0x20,0x51,0x74,0x57,0x61,0x79,0x6c,0x61,0x6e,0x64,0x2e,
  0x43,0x6f,0x6d,0x70,0x6f,0x73,0x69,0x74,0x6f,0x72,0x2e,0x57,0x6c,0x53,0x68,0x65,
  0x6c,0x6c,0xa,0x6c,0x69,0x6e,0x6b,0x74,0x61,0x72,0x67,0x65,0x74,0x20,0x51,0x74,
  0x36,0x3a,0x3a,0x57,0x61,0x79,0x6c,0x61,0x6e,0x64,0x43,0x6f,0x6d,0x70,0x6f,0x73,
  0x69,0x74,0x6f,0x72,0x57,0x4c,0x53,0x68,0x65,0x6c,0x6c,0x70,0x6c,0x75,0x67,0x69,
  0x6e,0xa,0x6f,0x70,0x74,0x69,0x6f,0x6e,0x61,0x6c,0x20,0x70,0x6c,0x75,0x67,0x69,
  0x6e,0x20,0x77,0x61,0x79,0x6c,0x61,0x6e,0x64,0x63,0x6f,0x6d,0x70,0x6f,0x73,0x69,
  0x74,0x6f,0x72,0x77,0x6c,0x73,0x68,0x65,0x6c,0x6c,0x70,0x6c,0x75,0x67,0x69,0x6e,
  0xa,0x63,0x6c,0x61,0x73,0x73,0x6e,0x61,0x6d,0x65,0x20,0x51,0x74,0x57,0x61,0x79,
  0x6c,0x61,0x6e,0x64,0x5f,0x43,0x6f,0x6d,0x70,0x6f,0x73,0x69,0x74,0x6f,0x72,0x5f,
  0x57,0x6c,0x53,0x68,0x65,0x6c,0x6c,0x50,0x6c,0x75,0x67,0x69,0x6e,0xa,0x74,0x79,
  0x70,0x65,0x69,0x6e,0x66,0x6f,0x20,0x70,0x6c,0x75,0x67,0x69,0x6e,0x73,0x2e,0x71,
  0x6d,0x6c,0x74,0x79,0x70,0x65,0x73,0xa,0x70,0x72,0x65,0x66,0x65,0x72,0x20,0x3a,
  0x2f,0x71,0x74,0x2d,0x70,0x72,0x6f,0x6a,0x65,0x63,0x74,0x2e,0x6f,0x72,0x67,0x2f,
  0x69,0x6d,0x70,0x6f,0x72,0x74,0x73,0x2f,0x51,0x74,0x57,0x61,0x79,0x6c,0x61,0x6e,
  0x64,0x2f,0x43,0x6f,0x6d,0x70,0x6f,0x73,0x69,0x74,0x6f,0x72,0x2f,0x57,0x6c,0x53,
  0x68,0x65,0x6c,0x6c,0x2f,0xa,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // qt-project.org
  0x0,0xe,
  0x5,0x28,0x6c,0x87,
  0x0,0x71,
  0x0,0x74,0x0,0x2d,0x0,0x70,0x0,0x72,0x0,0x6f,0x0,0x6a,0x0,0x65,0x0,0x63,0x0,0x74,0x0,0x2e,0x0,0x6f,0x0,0x72,0x0,0x67,
    // imports
  0x0,0x7,
  0x0,0x47,0x69,0x53,
  0x0,0x69,
  0x0,0x6d,0x0,0x70,0x0,0x6f,0x0,0x72,0x0,0x74,0x0,0x73,
    // QtWayland
  0x0,0x9,
  0xd,0x90,0x99,0x64,
  0x0,0x51,
  0x0,0x74,0x0,0x57,0x0,0x61,0x0,0x79,0x0,0x6c,0x0,0x61,0x0,0x6e,0x0,0x64,
    // Compositor
  0x0,0xa,
  0x7,0x63,0x47,0xe2,
  0x0,0x43,
  0x0,0x6f,0x0,0x6d,0x0,0x70,0x0,0x6f,0x0,0x73,0x0,0x69,0x0,0x74,0x0,0x6f,0x0,0x72,
    // WlShell
  0x0,0x7,
  0xe,0x19,0xec,0x8c,
  0x0,0x57,
  0x0,0x6c,0x0,0x53,0x0,0x68,0x0,0x65,0x0,0x6c,0x0,0x6c,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/imports
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/imports/QtWayland
  0x0,0x0,0x0,0x36,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/imports/QtWayland/Compositor
  0x0,0x0,0x0,0x4e,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/imports/QtWayland/Compositor/WlShell
  0x0,0x0,0x0,0x68,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x6,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/imports/QtWayland/Compositor/WlShell/qmldir
  0x0,0x0,0x0,0x7c,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9c,0xa,0xe6,0x57,0xe,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_QtWayland_Compositor_WlShell)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_QtWayland_Compositor_WlShell)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_QtWayland_Compositor_WlShell)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_QtWayland_Compositor_WlShell)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_QtWayland_Compositor_WlShell)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_QtWayland_Compositor_WlShell)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
